@@ -1432,6 +1432,7 @@ _g_local_file_info_get (const char             *basename,
   char *symlink_target;
   GVfs *vfs;
   GVfsClass *class;
+  guint64 device;
 
   info = g_file_info_new ();
 
@@ -1483,7 +1484,9 @@ _g_local_file_info_get (const char             *basename,
       g_free (display_name);
       return NULL;
     }
-  
+
+  device = statbuf.st_dev;
+
 #ifdef S_ISLNK
   is_symlink = S_ISLNK (statbuf.st_mode);
 #else
@@ -1709,18 +1712,9 @@ _g_local_file_info_get (const char             *basename,
   class = G_VFS_GET_CLASS (vfs);
   if (class->local_file_add_info)
     {
-      const char *extra_target;
-
-      extra_target = path;
-      if (!(flags & G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS) &&
-          is_symlink &&
-          !symlink_broken &&
-          symlink_target != NULL)
-        extra_target = symlink_target;
-
       class->local_file_add_info (vfs,
-                                  extra_target,
-                                  statbuf.st_dev,
+                                  path,
+                                  device,
                                   attribute_matcher,
                                   info,
                                   NULL,
